from setuptools import setup, find_packages

setup(
    name='morseme',
    packages = ['morseme'],
    version='0.1.2',
    description='A simple morse to human-readable-text converter',
    license='MIT',
    author='Hung Nguyen',
    author_email='hvngcs@gmail.com',
    url='https://github.com/hvng/morseme',
    download_url='https://github.com/hvng/morseme/releases/download/v0.1.2/morseme-0.1.2.tar.gz',
    keywords=['morse', 'morseme', ],
    classifiers=[
        'Development Status :: 4 - Beta',
        'Intended Audience :: Developers',
        'Topic :: Software Development :: Build Tools',
        'License :: OSI Approved :: MIT License',
        'Programming Language :: Python :: 3',
    ],
)
